@@ -214,7 +214,7 @@ impl<'a, W: Write> Encoder<'a, W> {
 
     /// Return a recommendation for the size of data to write at once.
     pub fn recommended_input_size() -> usize {
-        zstd_safe::cstream_in_size()
+        zstd_safe::CCtx::in_size()
     }
 
     crate::readwritecommon!(writer);
@@ -273,7 +273,10 @@ impl<'a, W: Write> Decoder<'a, W> {
         Ok(Decoder { writer })
     }
 
+    #[cfg(feature = "experimental")]
     /// Enables or disabled expecting the 4-byte magic header
+    ///
+    /// Only available with the `experimental` feature.
     pub fn include_magicbytes(
         &mut self,
         include_magicbytes: bool,
@@ -309,7 +312,7 @@ impl<'a, W: Write> Decoder<'a, W> {
 
     /// Return a recommendation for the size of data to write at once.
     pub fn recommended_input_size() -> usize {
-        zstd_safe::dstream_in_size()
+        zstd_safe::DCtx::in_size()
     }
 }
 
